@@ -30,7 +30,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '2.27';
+our $VERSION = '2.28';
 
 =head1 SYNOPSIS
 
@@ -118,7 +118,7 @@ Total number of running children allowed at any time. Defaults to 10. The comman
 has 'procs' => (
     is => 'rw',
     isa => 'Int',
-    default => 10,
+    default => 4,
     required => 0,
     documentation => q{Total number of running children allowed at any time. Defaults to 10. The command 'wait' can be used to have a variable number of children running. It is best to wrap this script in a slurm job to not overuse resources.}
 );
@@ -322,7 +322,11 @@ sub _log_commands {
     eval{
         $cmdpid = open3($infh, $outfh, $errfh, $self->cmd);
     };
-    #die $@ if $@;
+    die $@ if $@;
+    if(! $cmdpid) {
+        print "There is no $cmdpid please contact your administrator with the full command given\n";
+        die; 
+    }
     $infh->autoflush();
 
     $DB::single=2;
