@@ -27,7 +27,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '2.27';
+our $VERSION = '2.28';
 
 =head1 SYNOPSIS
 
@@ -252,19 +252,32 @@ EOF
     },
 );
 
-=head2 procs_per_sbatch
-
-Number of processes to use per sbatch. By default this is a conservative number as there is no checking mechanism to see how 'heavy' a job is.
+#This is redundant already in Runner::Init
+#=head2 procs_per_sbatch
+#
+#Number of processes to use per sbatch. By default this is a conservative number as there is no checking mechanism to see how 'heavy' a job is.
+#
+#=cut
+#
+#has procs_per_sbatch => (
+#    is => 'rw',
+#    isa => 'Int',
+#    default => 3,
+#    required => 0,
+#);
 
+=head2 serial
+Option to run all jobs serially, one after the other, no parallelism
+The default is to use 4 procs
 =cut
-
-has procs_per_sbatch => (
-    is => 'rw',
-    isa => 'Int',
-    default => 3,
-    required => 0,
+has serial => (
+    is        => 'rw',
+    isa     => 'Bool',
+    default => 0,
 );
 
+
+
 =head2 user
 
 user running the script. Passed to slurm for mail information
@@ -513,14 +526,17 @@ Calling system module load * does not work within a screen session!
 sub run {
     my $self = shift;
 
-    #This fails in a screen session!
-#    system("module load slurm");
-#    system("module load shared");
-    
-#    print "In run devel\n";
+    $DB::single=2;
+
     $self->logname('slurm_logs');
     $self->log($self->init_log);
-#    $self->log->info("hello world");
+
+    if($self->serial){
+        $self->procs(1);
+    }
+    else{
+        $self->procs(4);
+    }
 
     $self->check_files;
     $self->parse_file_slurm;
@@ -669,6 +685,7 @@ sub parse_file_slurm{
             #Run this batch and start the next
             $DB::single=2;
             $self->work;
+            push(@{$self->jobref}, []) if $self->serial;
         }
 
         if($self->has_cmd){
@@ -695,14 +712,13 @@ sub parse_file_slurm{
                 #submit this batch and get the job id so the next can depend upon it
                 $self->clear_cmd;
                 $self->wait(1);
-                #Keep this for debug info for now
-#                shift @{$self->jobref} if scalar @{$self->jobref} > 2;
                 $self->work if $self->has_batch;
                 push(@{$self->jobref}, []);
             }
             elsif( $self->match_cmd(qr/^newnode$/) ){
                 $self->clear_cmd;
                 $self->work if $self->has_batch;
+                push(@{$self->jobref}, []) if $self->serial;
             }
             else{
                 #Don't want to increase command count for wait and newnode
@@ -713,10 +729,8 @@ sub parse_file_slurm{
             $self->clear_cmd;
         }
     }
-#    print "Working!\n".Dumper($self->batch);
     $self->work if $self->has_batch;
-
-#    $self->log->debug("All the jobs ".Dumper($self->jobref));
+    push(@{$self->jobref}, []) if $self->serial;
 }
 
 =head2 work
@@ -777,11 +791,11 @@ sub process_batch{
 
     if($self->use_threads){
         $command = "cd ".getcwd()."\n"; #Go back to the working directory just to be safe
-        $command .= "paralellrunner.pl --procs ".$self->procs_per_sbatch." --infile ".$self->cmdfile." --outdir ".$self->outdir." --logname ".$self->jobname."_".$self->batch_counter;
+        $command .= "paralellrunner.pl --procs ".$self->procs." --infile ".$self->cmdfile." --outdir ".$self->outdir." --logname ".$self->jobname."_".$self->batch_counter;
     }
     elsif($self->use_processes){
         $command = "cd ".getcwd()."\n";
-        $command .= "mcerunner.pl --procs ".$self->procs_per_sbatch." --infile ".$self->cmdfile." --outdir ".$self->outdir." --logname ".$self->jobname."_".$self->batch_counter;
+        $command .= "mcerunner.pl --procs ".$self->procs." --infile ".$self->cmdfile." --outdir ".$self->outdir." --logname ".$self->jobname."_".$self->batch_counter;
     }
 
     $self->template->process($self->template_file, 
